.. _usage-label:

##########
Usage
##########

.. toctree::

   usage/startup
   usage/pdarray
   usage/creation
   usage/IO
   usage/arithmetic
   usage/indexing
   usage/histogram
   usage/argsort
   usage/setops
   usage/groupby
   usage/strings
   usage/categorical
